package de.mpg.mpimet.yacgui.ui.dialog.tabpanel;

import java.awt.Component;

import javax.swing.BoxLayout;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;

import de.mpg.mpimet.yacgui.xml.TransientCouple;

/**
 * Copyright (c) 2013 Max-Planck-Institute for Meteorology, Hamburg.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of Oracle or the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

public abstract class AbstractTab extends JPanel {
	
	public interface onCouplingDialogEventsListener {
		void updateWindowSize();
	}

	private static final long serialVersionUID = 2049961763853894034L;

	protected String dialogDescription;
	protected TransientCouple transientCouple;
	
	public AbstractTab(String dialogDescription, TransientCouple transientCouple) {
		this.dialogDescription = dialogDescription;
		this.transientCouple = transientCouple;
	}
	
	protected void createLayout() {
		setLayout(new BoxLayout(this, BoxLayout.PAGE_AXIS));
		add(createCaption());
		add(createCenterPanel());
	}

	protected JLabel createCaption() {
		JLabel label = new JLabel(convertToMultiline(dialogDescription));
		label.setAlignmentX(Component.CENTER_ALIGNMENT);
		label.setBorder(new EmptyBorder(5, 5, 5, 5));
		return label;
	}
	
	public static String convertToMultiline(String orig) {
	    return "<html>" + orig.replaceAll("\n", "<br>") + "</html>";
	}
	
	protected abstract JComponent createCenterPanel();
	public abstract void loadParameters();
}
