#!/usr/bin/env python3

##
# @file plot.py
# @brief receiving a field on a structured grid and plot it using matplotlib
#
# \example ex1_read_structured_netcdf/plot.py
# This example registers a field on a structured grid using the
# `Reg2dGrid` function. In the time loop it receives the data using
# `Field.get` function and generates a png image using matplotlib.
#
# @copyright Copyright  (C)  2022 DKRZ, MPI-M
#
# @author Nils-Arne Dreier <dreier@dkrz.de>
#

#
# Keywords:
# Maintainer: Nils-Arne Dreier <dreier@dkrz.de>
# URL: https://dkrz-sw.gitlab-pages.dkrz.de/yac/
#
# This file is part of YAC.
#
# Redistribution and use in source and binary forms, with or without
# modification, are  permitted provided that the following conditions are
# met:
#
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# Neither the name of the DKRZ GmbH nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#


from yac import *
import numpy as np
try:
    import matplotlib.pyplot as plt
except:
    pass

print(f"Moin! I'm using YAC version {version()}")

yac = YAC("coupling.xml", "coupling.xsd")

comp = yac.def_comp(f"C1")

x = np.linspace(0,2*np.pi,100)
y = np.linspace(-0.5*np.pi,0.5*np.pi,50)
grid = Reg2dGrid(f"grid1", x, y)
points = grid.def_points(Location.CORNER, x, y)

field = Field.create("example_field", comp, points)

yac.search()

buf = np.zeros((1,points.size))
time = yac.start_datetime
while True:
    buf, info = field.get(buf)
    try:
        plt.imshow(buf.reshape((len(y),len(x)))[::-1,::-1])
        plt.savefig(f"plot_{time}.png")
    except:
        pass
    time += field.model_timestep
    if info > 2:
        break
